@@ -10,4 +10,11 @@ class ServiceClient(ABC):
         self.system_prompt = system_prompt
 
     @abstractmethod
-    def create_chat_completion(self, messages: List[Message]) -> Message: ...
+    async def create_chat_completion(
+        self,
+        messages: List[Message]
+    ) -> Message:
+        ...
+
+    @abstractmethod
+    def model(self) -> str: ...
