@@ -1,4 +1,5 @@
 from typing import List
+from typing import Literal
 from typing import Optional
 
 from lark import Lark
@@ -12,10 +13,13 @@ GRAMMAR = """
 
     section: header content
 
-    header: "@@>" _WS ROLE ":" _WS
+    header: "@@>" _WS ROLE _WS "(" MODEL ")" ":" _WS
+        | "@@>" _WS ROLE ":" _WS
 
     ROLE: /[a-zA-Z]+/
 
+    MODEL: /.+(?=\\):\n)/x
+
     ?content: (line_without_header)*
 
     line_without_header: MARKDOWN
@@ -32,9 +36,14 @@ class Parser:
     def __init__(self) -> None:
         self.lark = Lark(GRAMMAR, parser='lalr')
         self.transformer = SectionTransformer()
+        self.last_failed_document: Optional[str] | Literal[False] = False
 
     def parse(self, document: Optional[str]) -> List[Message]:
-        if not document or not document.strip():
-            return []
-        tree = self.lark.parse(document.lstrip())
-        return self.transformer.transform(tree)
+        try:
+            if not document or not document.strip():
+                return []
+            tree = self.lark.parse(document.lstrip())
+            return self.transformer.transform(tree)
+        except Exception as e:
+            self.last_failed_document = document.lstrip() if document else None
+            raise e
