@@ -18,14 +18,16 @@ def generate_file_content(messages: List[Message]) -> str:
     if not messages:
         return ""
     result = map(
-        lambda message: f"@@> {message.role}:\n{message.content.strip()}",
+        lambda message: f"""\
+@@> {message.role}{f' ({message.model})' if message.model else ''}:
+{message.content.strip()}""",
         messages
     )
     return "\n\n".join(result) + "\n\n"
 
 
 def _hash_messages(
-    messages: list[Message], length: int = 5
+    messages: Iterable[Message], length: int = 5
 ) -> str:
     data: Iterable = list(messages)
     data = map(lambda m: m.content, data)
@@ -35,16 +37,24 @@ def _hash_messages(
     return format(checksum, 'x').zfill(length)[:length]
 
 
-def generate_filename(
+async def generate_filename(
     client: ServiceClient,
     summary_prompt: str,
-    messages: List[Message],
+    messages: Iterable[Message],
     extension: str
 ) -> str:
     summarize_prompt = Message(role="user", content=summary_prompt)
-    content = client.create_chat_completion(
+    content = (await client.create_chat_completion(
         [*messages, summarize_prompt]
-    ).content
+    )).content
+    return generate_filename_from_response(content, messages, extension)
+
+
+def generate_filename_from_response(
+    content: str,
+    messages: Iterable[Message],
+    extension: str
+) -> str:
     filename = content.strip()
     filename = filename.lower()
     filename = filename.replace(' ', '-')
