@@ -27,7 +27,8 @@ class Renderer:
         self.console = Console(width=markdown_max_width)
 
     def render(self, message: Message) -> str:
-        markdown = self.get_markdown(message.content)
+        content = f'# {message.model}\n{message.content}'
+        markdown = self.get_markdown(content)
         with self.console.capture() as capture:
             self.console.print(markdown)
         return capture.get()
