@@ -1,8 +1,6 @@
-from unittest.mock import MagicMock
-
 from pytest import mark
 
-from dotchatbot.output.file import generate_filename
+from dotchatbot.output.file import generate_filename_from_response
 
 
 @mark.parametrize(
@@ -13,10 +11,7 @@ from dotchatbot.output.file import generate_filename
         "   Test Filename Some's Invalid!   ",
         "test-filename-somes-invalid-00000.dcb"), ]
 )
-def test_generate_filename(summary: str, expected: str) -> None:
-    mock_client = MagicMock()
-    mock_client.create_chat_completion.return_value.content = summary
-
-    assert generate_filename(
-        mock_client, 'Summarize', [], '.dcb'
+def test_generate_filename_from_response(summary: str, expected: str) -> None:
+    assert generate_filename_from_response(
+        summary, [], '.dcb'
     ) == expected
