@@ -34,19 +34,35 @@ def parser() -> Parser:
                 Message(role="user", content="test\nthis\nis\na\ntest\n"),
             ]
         ),
-
         (
             "@@> user:\n"
             "one\n"
-            "@@> assistant:\n"
+            "@@> assistant (test):\n"
             "two\n"
             "@@> user:\n"
             "three\n",
             [
                 Message(role="user", content="one\n"),
-                Message(role="assistant", content="two\n"),
+                Message(role="assistant", model='test', content="two\n"),
                 Message(role="user", content="three\n"),
             ],
+        ),
+        (
+                "@@> user:\n"
+                "one\n"
+                "@@> assistant (unusual model name<>.2932938ds8):):(():):\n"
+                "two\n"
+                "@@> user:\n"
+                "three\n",
+                [
+                    Message(role="user", content="one\n"),
+                    Message(
+                        role="assistant",
+                        model='unusual model name<>.2932938ds8):):(():',
+                        content="two\n"
+                    ),
+                    Message(role="user", content="three\n"),
+                ],
         )
     ]
 )
